# osxstrap

Everything you need to provision your OSX workstation in a standardized, modern, and easily customizable way, powered by Ansible.

## Quick Start
 
## Issues

Please report any issues to this repositories issue tracker https://github.com/osxstrap/osxstrap/issues.

## Credits

Created by [Jeremy Litten](https://github.com/jeremyltn).

Inspired by

https://github.com/superlumic

https://github.com/spencergibb/ansible-osx

https://github.com/debops

and many others.

See individual repositories at https://github.com/osxstrap for Ansible role credits.